@@ -3,14 +3,13 @@
 require 'test_helper'
 
 class TestDescribe < Test::Unit::TestCase
-
   def setup
     clone_working_repo
     @git = Git.open(@wdir)
   end
 
   def test_describe
-    assert_equal(@git.describe(nil, {:tags => true}), 'grep_colon_numbers')
+    assert_equal(@git.describe(nil, { tags: true }), 'grep_colon_numbers')
   end
 
   def test_describe_with_invalid_commitish
