@@ -4,7 +4,8 @@ require 'test_helper'
 
 class TestTimeoutError < Test::Unit::TestCase
   def test_initializer
-    status = Struct.new(:to_s).new('pid 65628 SIGKILL (signal 9)') # `kill -9 $$`
+    # `kill -9 $$`
+    status = Class.new { def to_s = 'pid 65628 SIGKILL (signal 9)' }.new
     result = Git::CommandLineResult.new(%w[git status], status, 'stdout', 'stderr')
     timeout_diration = 10
 
@@ -14,7 +15,8 @@ class TestTimeoutError < Test::Unit::TestCase
   end
 
   def test_to_s
-    status = Struct.new(:to_s).new('pid 65628 SIGKILL (signal 9)') # `kill -9 $$`
+    # `kill -9 $$`
+    status = Class.new { def to_s = 'pid 65628 SIGKILL (signal 9)' }.new
     result = Git::CommandLineResult.new(%w[git status], status, 'stdout', 'Waiting...')
     timeout_duration = 10
 
